==> qmmp-plugin-pack_1.6.1.orig.tar.xz: src/Engines/ffvideo/translations/ffvideo_plugin_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>FFVideoFactory</name>
    <message>
        <location filename="../ffvideofactory.cpp" line="42"/>
        <source>FFmpeg Video Plugin</source>
        <translation>Suplemento FFmpeg Video</translation>
    </message>
    <message>
        <location filename="../ffvideofactory.cpp" line="46"/>
        <source>Video Files</source>
        <translation>Ficheiros de vídeo</translation>
    </message>
    <message>
        <location filename="../ffvideofactory.cpp" line="160"/>
        <source>About FFVideo Plugin</source>
        <translation>Acerca de suplemento FFVideo</translation>
    </message>
    <message>
        <location filename="../ffvideofactory.cpp" line="161"/>
        <source>FFmpeg-based video plugin for Qmmp</source>
        <translation>Suplemento FFmpeg Video para o Qmmp</translation>
    </message>
    <message>
        <location filename="../ffvideofactory.cpp" line="162"/>
        <source>Compiled against:</source>
        <translation>Compilado com:</translation>
    </message>
    <message>
        <location filename="../ffvideofactory.cpp" line="172"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Desenvolvido por: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>FFVideoMetaDataModel</name>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="50"/>
        <source>File size</source>
        <translation>Tamanho do ficheiro</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="51"/>
        <source>Bitrate</source>
        <translation>Taxa de dados</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="70"/>
        <source>Audio bitrate</source>
        <translation>Taxa de dados do áudio</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="71"/>
        <source>Audio sample rate</source>
        <translation>Frequência de áudio</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="50"/>
        <source>KiB</source>
        <translation>KiB</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="51"/>
        <location filename="../ffvideometadatamodel.cpp" line="70"/>
        <location filename="../ffvideometadatamodel.cpp" line="83"/>
        <source>kbps</source>
        <translation>kbps</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="71"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="73"/>
        <location filename="../ffvideometadatamodel.cpp" line="75"/>
        <source>Audio channels</source>
        <translation>Canais de áudio</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="82"/>
        <source>Video size</source>
        <translation>Tamanho do vídeo</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="83"/>
        <source>Video bitrate</source>
        <translation>Taxa de dados do vídeo</translation>
    </message>
</context>
<context>
    <name>VideoWindow</name>
    <message>
        <location filename="../videowindow.cpp" line="40"/>
        <source>FFmpeg Video</source>
        <translation>FFmpeg Video</translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="45"/>
        <source>&amp;Pause</source>
        <translation>&amp;Pausa</translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="45"/>
        <source>Space</source>
        <translation>Espaço</translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="46"/>
        <source>&amp;Stop</source>
        <translation>Pa&amp;rar</translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="46"/>
        <source>V</source>
        <translation>V</translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="48"/>
        <source>&amp;Fullscreen</source>
        <translation>&amp;Ecrã completo</translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="48"/>
        <source>F</source>
        <translation>F</translation>
    </message>
</context>
</TS>

==> qmmp-plugin-pack_1.7.1.orig.tar.xz: src/Engines/ffvideo/translations/ffvideo_plugin_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>FFVideoFactory</name>
    <message>
        <location filename="../ffvideofactory.cpp" line="41"/>
        <source>FFmpeg Video Plugin</source>
        <translation>Suplemento FFmpeg Video</translation>
    </message>
    <message>
        <location filename="../ffvideofactory.cpp" line="45"/>
        <source>Video Files</source>
        <translation>Ficheiros de vídeo</translation>
    </message>
    <message>
        <location filename="../ffvideofactory.cpp" line="161"/>
        <source>About FFVideo Plugin</source>
        <translation>Acerca de suplemento FFVideo</translation>
    </message>
    <message>
        <location filename="../ffvideofactory.cpp" line="162"/>
        <source>FFmpeg-based video plugin for Qmmp</source>
        <translation>Suplemento FFmpeg Video para o Qmmp</translation>
    </message>
    <message>
        <location filename="../ffvideofactory.cpp" line="163"/>
        <source>Compiled against:</source>
        <translation>Compilado com:</translation>
    </message>
    <message>
        <location filename="../ffvideofactory.cpp" line="172"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Desenvolvido por: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>FFVideoMetaDataModel</name>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="50"/>
        <source>File size</source>
        <translation>Tamanho do ficheiro</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="51"/>
        <source>Bitrate</source>
        <translation>Taxa de dados</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="70"/>
        <source>Audio bitrate</source>
        <translation>Taxa de dados de áudio</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="71"/>
        <source>Audio sample rate</source>
        <translation>Frequência de áudio</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="50"/>
        <source>KiB</source>
        <translation>KiB</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="51"/>
        <location filename="../ffvideometadatamodel.cpp" line="70"/>
        <location filename="../ffvideometadatamodel.cpp" line="83"/>
        <source>kbps</source>
        <translation>kbps</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="71"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="73"/>
        <location filename="../ffvideometadatamodel.cpp" line="75"/>
        <source>Audio channels</source>
        <translation>Canais de áudio</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="82"/>
        <source>Video size</source>
        <translation>Tamanho do vídeo</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="83"/>
        <source>Video bitrate</source>
        <translation>Taxa de dados do vídeo</translation>
    </message>
</context>
<context>
    <name>VideoWindow</name>
    <message>
        <location filename="../videowindow.cpp" line="40"/>
        <source>FFmpeg Video</source>
        <translation>FFmpeg Video</translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="45"/>
        <source>&amp;Pause</source>
        <translation>&amp;Pausa</translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="45"/>
        <source>Space</source>
        <translation>Espaço</translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="46"/>
        <source>&amp;Stop</source>
        <translation>Pa&amp;rar</translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="46"/>
        <source>V</source>
        <translation>V</translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="48"/>
        <source>&amp;Fullscreen</source>
        <translation>&amp;Ecrã completo</translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="48"/>
        <source>F</source>
        <translation>F</translation>
    </message>
</context>
</TS>
